from typing import List
from datetime import datetime
from monty.json import MontyDecoder
from pydantic import BaseModel, Field, validator


class FermiDoc(BaseModel):
    """
    Fermi surfaces.
    """

    fermi_surfaces: List[dict] = Field(
        None,
        description="List of IFermi FermiSurface objects.",
    )

    surface_types: List[str] = Field(
        None,
        description="Type of each fermi surface in the fermi_surfaces list.\
            Is either CBM or VBM for semiconductors, or fermi_surface for metals.",
    )

    task_id: str = Field(
        None,
        description="The Materials Project ID of the material. This comes in the form: mp-******.",
    )

    last_updated: datetime = Field(
        None,
        description="Timestamp for the most recent calculation for this fermi surface document.",
    )

    # Make sure that the datetime field is properly formatted
    @validator("last_updated", pre=True)
    def last_updated_dict_ok(cls, v):
        return MontyDecoder().process_decoded(v)



import pytest
from monty.serialization import loadfn
from emmet.core.molecules.summary import SummaryDoc


@pytest.fixture(scope="session")
def docs_data(test_dir):
    raw = loadfn(test_dir / "35883c6709ca5ee9d065d088bae2cd4e-C3H4Li1O3-0-2.json")
    return raw


def test_summary_doc(docs_data):
    summary_doc = SummaryDoc.from_docs(molecule_id="35883c6709ca5ee9d065d088bae2cd4e-C3H4Li1O3-0-2", docs=docs_data)

    assert summary_doc.property_name == "summary"
    assert summary_doc.electronic_energy is not None
    assert summary_doc.total_enthalpy is not None
    assert summary_doc.frequencies is not None
    assert summary_doc.nbo_population is None
    assert summary_doc.electron_affinity is None
    assert summary_doc.bonds is not None
